@@ -110,6 +110,7 @@ class View::Impl : public SmallObject<> {
     }
 
     virtual bool Call(MainLoopInterface *main_loop, int watch_id) {
+      GGL_UNUSED(watch_id);
       ASSERT(event_.GetToken() == watch_id);
       ScopedLogContext log_context(impl_->gadget_);
 
@@ -156,6 +157,8 @@ class View::Impl : public SmallObject<> {
     }
 
     virtual void OnRemove(MainLoopInterface *main_loop, int watch_id) {
+      GGL_UNUSED(main_loop);
+      GGL_UNUSED(watch_id);
       ASSERT(event_.GetToken() == watch_id);
       delete this;
     }
@@ -401,7 +404,10 @@ class View::Impl : public SmallObject<> {
       // We used to check IsReallyEnabled() here, which seems too strict
       // because the grabmouse_element_ may move out of the visible area, but
       // it should still grab the mouse.
-      if (grabmouse_element_.Get()->IsEnabled() &&
+      // EVENT_MOUSE_UP should always be fired no matter if the element is
+      // enabled or not.
+      if ((grabmouse_element_.Get()->IsEnabled() ||
+           type == Event::EVENT_MOUSE_UP) &&
           (event.GetButton() & MouseEvent::BUTTON_LEFT) &&
           (type == Event::EVENT_MOUSE_MOVE || type == Event::EVENT_MOUSE_UP ||
            type == Event::EVENT_MOUSE_CLICK)) {
@@ -685,7 +691,7 @@ class View::Impl : public SmallObject<> {
   void SetFocusToFirstElement() {
     if (children_.GetCount()) {
       BasicElement *first = children_.GetItemByIndex(0);
-      if (!first->IsTabStop())
+      if (!first->IsReallyEnabled() || !first->IsTabStop())
         first = GetNextFocusElement(first);
       SetFocus(first);
     }
@@ -695,7 +701,7 @@ class View::Impl : public SmallObject<> {
     size_t count = children_.GetCount();
     if (count) {
       BasicElement *last = children_.GetItemByIndex(count - 1);
-      if (!last->IsTabStop())
+      if (!last->IsReallyEnabled() || !last->IsTabStop())
         last = GetPreviousFocusElement(last);
       SetFocus(last);
     }
@@ -785,7 +791,8 @@ class View::Impl : public SmallObject<> {
   }
 
   BasicElement *GetFirstFocusInTree(BasicElement *current) {
-    return current->IsTabStop() ? current : GetFirstFocusInSubTrees(current);
+    return current->IsReallyEnabled() && current->IsTabStop() ?
+           current : GetFirstFocusInSubTrees(current);
   }
 
   BasicElement *GetFirstFocusInSubTrees(BasicElement *current) {
@@ -808,7 +815,7 @@ class View::Impl : public SmallObject<> {
     BasicElement *result = GetLastFocusInSubTrees(current);
     if (result)
       return result;
-    return current->IsTabStop() ? current : NULL;
+    return current->IsReallyEnabled() && current->IsTabStop() ? current : NULL;
   }
 
   BasicElement *GetLastFocusInSubTrees(BasicElement *current) {
@@ -2250,6 +2257,10 @@ int View::GetDefaultFontSize() const {
          impl_->gadget_->GetDefaultFontSize() : kDefaultFontSize;
 }
 
+bool View::IsFocused() const {
+  return impl_->view_focused_;
+}
+
 Connection *View::ConnectOnCancelEvent(Slot0<void> *handler) {
   return impl_->oncancel_event_.Connect(handler);
 }
